# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/search.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/search.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x12\x61nndb/search.proto\x12\x08\x61nndb_pb\"=\n\rSearchRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\r\n\x05query\x18\x02 \x03(\x02\x12\t\n\x01k\x18\x03 \x01(\r\"^\n\x17SearchPartitionsRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\x15\n\rpartition_ids\x18\x02 \x03(\x0c\x12\r\n\x05query\x18\x03 \x03(\x02\x12\t\n\x01k\x18\x04 \x01(\r\"\x9a\x01\n\x10SearchResultItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12:\n\x08metadata\x18\x02 \x03(\x0b\x32(.anndb_pb.SearchResultItem.MetadataEntry\x12\r\n\x05score\x18\x03 \x01(\x02\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x9e\x01\n\x06Search\x12?\n\x06Search\x12\x17.anndb_pb.SearchRequest\x1a\x1a.anndb_pb.SearchResultItem0\x01\x12S\n\x10SearchPartitions\x12!.anndb_pb.SearchPartitionsRequest\x1a\x1a.anndb_pb.SearchResultItem0\x01\x62\x06proto3')
)




_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='anndb_pb.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.SearchRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='anndb_pb.SearchRequest.query', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='k', full_name='anndb_pb.SearchRequest.k', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=93,
)


_SEARCHPARTITIONSREQUEST = _descriptor.Descriptor(
  name='SearchPartitionsRequest',
  full_name='anndb_pb.SearchPartitionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.SearchPartitionsRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_ids', full_name='anndb_pb.SearchPartitionsRequest.partition_ids', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='anndb_pb.SearchPartitionsRequest.query', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='k', full_name='anndb_pb.SearchPartitionsRequest.k', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=189,
)


_SEARCHRESULTITEM_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.SearchResultItem.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.SearchResultItem.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.SearchResultItem.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=346,
)

_SEARCHRESULTITEM = _descriptor.Descriptor(
  name='SearchResultItem',
  full_name='anndb_pb.SearchResultItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.SearchResultItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.SearchResultItem.metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='anndb_pb.SearchResultItem.score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SEARCHRESULTITEM_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=346,
)

_SEARCHRESULTITEM_METADATAENTRY.containing_type = _SEARCHRESULTITEM
_SEARCHRESULTITEM.fields_by_name['metadata'].message_type = _SEARCHRESULTITEM_METADATAENTRY
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['SearchPartitionsRequest'] = _SEARCHPARTITIONSREQUEST
DESCRIPTOR.message_types_by_name['SearchResultItem'] = _SEARCHRESULTITEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHREQUEST,
  __module__ = 'anndb.search_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.SearchRequest)
  ))
_sym_db.RegisterMessage(SearchRequest)

SearchPartitionsRequest = _reflection.GeneratedProtocolMessageType('SearchPartitionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPARTITIONSREQUEST,
  __module__ = 'anndb.search_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.SearchPartitionsRequest)
  ))
_sym_db.RegisterMessage(SearchPartitionsRequest)

SearchResultItem = _reflection.GeneratedProtocolMessageType('SearchResultItem', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _SEARCHRESULTITEM_METADATAENTRY,
    __module__ = 'anndb.search_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.SearchResultItem.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _SEARCHRESULTITEM,
  __module__ = 'anndb.search_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.SearchResultItem)
  ))
_sym_db.RegisterMessage(SearchResultItem)
_sym_db.RegisterMessage(SearchResultItem.MetadataEntry)


_SEARCHRESULTITEM_METADATAENTRY._options = None

_SEARCH = _descriptor.ServiceDescriptor(
  name='Search',
  full_name='anndb_pb.Search',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=349,
  serialized_end=507,
  methods=[
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='anndb_pb.Search.Search',
    index=0,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SEARCHRESULTITEM,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SearchPartitions',
    full_name='anndb_pb.Search.SearchPartitions',
    index=1,
    containing_service=None,
    input_type=_SEARCHPARTITIONSREQUEST,
    output_type=_SEARCHRESULTITEM,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SEARCH)

DESCRIPTOR.services_by_name['Search'] = _SEARCH

# @@protoc_insertion_point(module_scope)



from typing import Iterator
from uuid import UUID

from anndb.dataset_pb2_grpc import DatasetManagerStub, DataManagerStub
from anndb.search_pb2_grpc import SearchStub
from anndb.dataset_pb2 import Dataset as DatasetPb, Space as SpacePb
from anndb.core_pb2 import UUIDRequest, EmptyMessage

from anndb.dataset import Dataset

class DatasetManager:

	def __init__(self, conn):
		self._conn = conn
		self._dataset_manager_stub = DatasetManagerStub(conn)
		self._data_manager_stub = DataManagerStub(conn)
		self._search_stub = SearchStub(conn)

	def list(self) -> Iterator[DatasetPb]:
		for pb in self._dataset_manager_stub.List(EmptyMessage()):
			yield pb

	def get(self, id:UUID) -> Dataset:
		proto = self._dataset_manager_stub.Get(UUIDRequest(id=id.bytes))

		return Dataset(self._data_manager_stub, self._search_stub, proto)

	def create(self, dim:int, space:SpacePb, partition_count:int=1, replication_factor:int=3) -> Dataset:
		proto = self._dataset_manager_stub.Create(DatasetPb(
			dimension=dim,
			space=space,
			partition_count=partition_count,
			replication_factor=replication_factor
		))

		return Dataset(self._data_manager_stub, self._search_stub, proto)

	def delete(self, id:UUID):
		self._dataset_manager_stub.Delete(UUIDRequest(id=id))


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from anndb import cluster_pb2 as anndb_dot_cluster__pb2
from anndb import core_pb2 as anndb_dot_core__pb2


class NodesManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListNodes = channel.unary_stream(
        '/anndb_pb.NodesManager/ListNodes',
        request_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
        response_deserializer=anndb_dot_cluster__pb2.Node.FromString,
        )
    self.AddNode = channel.unary_stream(
        '/anndb_pb.NodesManager/AddNode',
        request_serializer=anndb_dot_cluster__pb2.Node.SerializeToString,
        response_deserializer=anndb_dot_cluster__pb2.Node.FromString,
        )
    self.RemoveNode = channel.unary_unary(
        '/anndb_pb.NodesManager/RemoveNode',
        request_serializer=anndb_dot_cluster__pb2.Node.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )


class NodesManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ListNodes(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddNode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveNode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodesManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListNodes': grpc.unary_stream_rpc_method_handler(
          servicer.ListNodes,
          request_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
          response_serializer=anndb_dot_cluster__pb2.Node.SerializeToString,
      ),
      'AddNode': grpc.unary_stream_rpc_method_handler(
          servicer.AddNode,
          request_deserializer=anndb_dot_cluster__pb2.Node.FromString,
          response_serializer=anndb_dot_cluster__pb2.Node.SerializeToString,
      ),
      'RemoveNode': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveNode,
          request_deserializer=anndb_dot_cluster__pb2.Node.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.NodesManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from anndb import core_pb2 as anndb_dot_core__pb2
from anndb import dataset_pb2 as anndb_dot_dataset__pb2


class DatasetManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/anndb_pb.DatasetManager/List',
        request_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Get = channel.unary_unary(
        '/anndb_pb.DatasetManager/Get',
        request_serializer=anndb_dot_core__pb2.UUIDRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Create = channel.unary_unary(
        '/anndb_pb.DatasetManager/Create',
        request_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Delete = channel.unary_unary(
        '/anndb_pb.DatasetManager/Delete',
        request_serializer=anndb_dot_core__pb2.UUIDRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )


class DatasetManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DatasetManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=anndb_dot_core__pb2.UUIDRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=anndb_dot_core__pb2.UUIDRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.DatasetManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class DataManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Insert = channel.unary_unary(
        '/anndb_pb.DataManager/Insert',
        request_serializer=anndb_dot_dataset__pb2.InsertRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.Update = channel.unary_unary(
        '/anndb_pb.DataManager/Update',
        request_serializer=anndb_dot_dataset__pb2.UpdateRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.Remove = channel.unary_unary(
        '/anndb_pb.DataManager/Remove',
        request_serializer=anndb_dot_dataset__pb2.RemoveRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.BatchInsert = channel.unary_unary(
        '/anndb_pb.DataManager/BatchInsert',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.BatchUpdate = channel.unary_unary(
        '/anndb_pb.DataManager/BatchUpdate',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.BatchRemove = channel.unary_unary(
        '/anndb_pb.DataManager/BatchRemove',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchInsert = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchInsert',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchUpdate = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchUpdate',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchRemove = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchRemove',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )


class DataManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Insert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Remove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchInsert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchUpdate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchRemove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchInsert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchUpdate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchRemove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Insert': grpc.unary_unary_rpc_method_handler(
          servicer.Insert,
          request_deserializer=anndb_dot_dataset__pb2.InsertRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=anndb_dot_dataset__pb2.UpdateRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'Remove': grpc.unary_unary_rpc_method_handler(
          servicer.Remove,
          request_deserializer=anndb_dot_dataset__pb2.RemoveRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'BatchInsert': grpc.unary_unary_rpc_method_handler(
          servicer.BatchInsert,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'BatchUpdate': grpc.unary_unary_rpc_method_handler(
          servicer.BatchUpdate,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'BatchRemove': grpc.unary_unary_rpc_method_handler(
          servicer.BatchRemove,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchInsert': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchInsert,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchUpdate': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchUpdate,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchRemove': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchRemove,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.DataManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import grpc

from anndb.dataset_manager import DatasetManager

class Client:

	def __init__(self, addr):
		self._conn = grpc.insecure_channel(addr)
		self._dataset_manager = DatasetManager(self._conn)

	@property
	def datasets(self):
		return self._dataset_manager
	



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/core.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/core.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x10\x61nndb/core.proto\x12\x08\x61nndb_pb\"\x0e\n\x0c\x45mptyMessage\"\x19\n\x0bUUIDRequest\x12\n\n\x02id\x18\x01 \x01(\x0c\x62\x06proto3')
)




_EMPTYMESSAGE = _descriptor.Descriptor(
  name='EmptyMessage',
  full_name='anndb_pb.EmptyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=44,
)


_UUIDREQUEST = _descriptor.Descriptor(
  name='UUIDRequest',
  full_name='anndb_pb.UUIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.UUIDRequest.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=71,
)

DESCRIPTOR.message_types_by_name['EmptyMessage'] = _EMPTYMESSAGE
DESCRIPTOR.message_types_by_name['UUIDRequest'] = _UUIDREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmptyMessage = _reflection.GeneratedProtocolMessageType('EmptyMessage', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYMESSAGE,
  __module__ = 'anndb.core_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.EmptyMessage)
  ))
_sym_db.RegisterMessage(EmptyMessage)

UUIDRequest = _reflection.GeneratedProtocolMessageType('UUIDRequest', (_message.Message,), dict(
  DESCRIPTOR = _UUIDREQUEST,
  __module__ = 'anndb.core_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.UUIDRequest)
  ))
_sym_db.RegisterMessage(UUIDRequest)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anndb import core_pb2 as anndb_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/cluster.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x13\x61nndb/cluster.proto\x12\x08\x61nndb_pb\x1a\x10\x61nndb/core.proto\"#\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t2\xa8\x01\n\x0cNodesManager\x12\x35\n\tListNodes\x12\x16.anndb_pb.EmptyMessage\x1a\x0e.anndb_pb.Node0\x01\x12+\n\x07\x41\x64\x64Node\x12\x0e.anndb_pb.Node\x1a\x0e.anndb_pb.Node0\x01\x12\x34\n\nRemoveNode\x12\x0e.anndb_pb.Node\x1a\x16.anndb_pb.EmptyMessageb\x06proto3')
  ,
  dependencies=[anndb_dot_core__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='anndb_pb.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Node.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='anndb_pb.Node.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=86,
)

DESCRIPTOR.message_types_by_name['Node'] = _NODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'anndb.cluster_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Node)
  ))
_sym_db.RegisterMessage(Node)



_NODESMANAGER = _descriptor.ServiceDescriptor(
  name='NodesManager',
  full_name='anndb_pb.NodesManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=89,
  serialized_end=257,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListNodes',
    full_name='anndb_pb.NodesManager.ListNodes',
    index=0,
    containing_service=None,
    input_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    output_type=_NODE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddNode',
    full_name='anndb_pb.NodesManager.AddNode',
    index=1,
    containing_service=None,
    input_type=_NODE,
    output_type=_NODE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveNode',
    full_name='anndb_pb.NodesManager.RemoveNode',
    index=2,
    containing_service=None,
    input_type=_NODE,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODESMANAGER)

DESCRIPTOR.services_by_name['NodesManager'] = _NODESMANAGER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from anndb import search_pb2 as anndb_dot_search__pb2


class SearchStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Search = channel.unary_stream(
        '/anndb_pb.Search/Search',
        request_serializer=anndb_dot_search__pb2.SearchRequest.SerializeToString,
        response_deserializer=anndb_dot_search__pb2.SearchResultItem.FromString,
        )
    self.SearchPartitions = channel.unary_stream(
        '/anndb_pb.Search/SearchPartitions',
        request_serializer=anndb_dot_search__pb2.SearchPartitionsRequest.SerializeToString,
        response_deserializer=anndb_dot_search__pb2.SearchResultItem.FromString,
        )


class SearchServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Search(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SearchPartitions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Search': grpc.unary_stream_rpc_method_handler(
          servicer.Search,
          request_deserializer=anndb_dot_search__pb2.SearchRequest.FromString,
          response_serializer=anndb_dot_search__pb2.SearchResultItem.SerializeToString,
      ),
      'SearchPartitions': grpc.unary_stream_rpc_method_handler(
          servicer.SearchPartitions,
          request_deserializer=anndb_dot_search__pb2.SearchPartitionsRequest.FromString,
          response_serializer=anndb_dot_search__pb2.SearchResultItem.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.Search', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from uuid import UUID

from typing import List, Iterator, Tuple, Mapping

from anndb.dataset_pb2_grpc import DataManagerStub
from anndb.search_pb2_grpc import SearchStub
from anndb.dataset_pb2 import Dataset as DatasetPb, InsertRequest, RemoveRequest, BatchRequest, BatchItem
from anndb.search_pb2 import SearchRequest

class Dataset:

	def __init__(self, data_manager_stub:DataManagerStub, search_stub:SearchStub, proto:DatasetPb):
		self._data_manager_stub = data_manager_stub
		self._search_stub = search_stub
		self._proto = proto

	@property
	def id(self):
		return UUID(bytes=self._proto.id)

	@property
	def proto(self):
		return self._proto

	def insert(self, id:int, value:List[float], metadata:Mapping[str,str] = {}):
		return self._data_manager_stub.Insert(InsertRequest(
			dataset_id=self.proto.id,
			id=id,
			value=value,
			metadata=metadata
			))

	def batch_insert(self, items:List[Tuple[int, List[float], Mapping[str,str]]]):
		return self._data_manager_stub.BatchInsert(BatchRequest(
			dataset_id=self.proto.id,
			items=list(map(
				lambda t: BatchItem(id=t[0], value=t[1], metadata=t[2]),
				items
				))
			))

	def remove(self, id:int):
		return self._data_manager_stub.Remove(RemoveRequest(
			dataset_id=self.proto.id,
			id=id,
			))

	def batch_remove(self, ids:List[int]):
		return self._data_manager_stub.BatchRemove(BatchRequest(
			dataset_id=self.proto.id,
			items=list(map(
				lambda id: BatchItem(id=id),
				ids
				))
			))

	def search(self, query:List[float], k:int) -> Iterator[Tuple[int, Mapping[str,str], float]]:
		request = SearchRequest(dataset_id=self.proto.id, query=query, k=k)

		for item in self._search_stub.Search(request):
			yield (item.id, item.metadata, item.score)


# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/dataset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anndb import core_pb2 as anndb_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/dataset.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x13\x61nndb/dataset.proto\x12\x08\x61nndb_pb\x1a\x10\x61nndb/core.proto\"\xa8\x01\n\rInsertRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x03(\x02\x12\x37\n\x08metadata\x18\x04 \x03(\x0b\x32%.anndb_pb.InsertRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\rUpdateRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x03(\x02\x12\x37\n\x08metadata\x18\x04 \x03(\x0b\x32%.anndb_pb.UpdateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rRemoveRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\"\x9b\x01\n\tBatchItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x03(\x02\x12\x33\n\x08metadata\x18\x03 \x03(\x0b\x32!.anndb_pb.BatchItem.MetadataEntry\x12\r\n\x05level\x18\x04 \x01(\x05\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x0c\x42\x61tchRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.anndb_pb.BatchItem\"e\n\x15PartitionBatchRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\x14\n\x0cpartition_id\x18\x02 \x01(\x0c\x12\"\n\x05items\x18\x03 \x03(\x0b\x32\x13.anndb_pb.BatchItem\"s\n\rBatchResponse\x12\x33\n\x06\x65rrors\x18\x01 \x03(\x0b\x32#.anndb_pb.BatchResponse.ErrorsEntry\x1a-\n\x0b\x45rrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x01\n\x07\x44\x61taset\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x11\n\tdimension\x18\x02 \x01(\r\x12\x1e\n\x05space\x18\x03 \x01(\x0e\x32\x0f.anndb_pb.Space\x12\x17\n\x0fpartition_count\x18\x04 \x01(\r\x12\x1a\n\x12replication_factor\x18\x05 \x01(\r\x12\'\n\npartitions\x18\x06 \x03(\x0b\x32\x13.anndb_pb.Partition\")\n\tPartition\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x10\n\x08node_ids\x18\x02 \x03(\x04\"o\n\x14\x44\x61tasetManagerChange\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".anndb_pb.DatasetManagerChangeType\x12\x17\n\x0fnotification_id\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x91\x01\n\x1b\x44\x61tasetPartitionNodesChange\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).anndb_pb.DatasetPartitionNodesChangeType\x12\x12\n\ndataset_id\x18\x02 \x01(\x0c\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x0c\x12\x0f\n\x07node_id\x18\x04 \x01(\x04\"\x97\x02\n\x0fPartitionChange\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.anndb_pb.PartitionChangeType\x12\x17\n\x0fnotification_id\x18\x02 \x01(\x0c\x12\n\n\x02id\x18\x03 \x01(\x04\x12\r\n\x05value\x18\x04 \x03(\x02\x12\x39\n\x08metadata\x18\x05 \x03(\x0b\x32\'.anndb_pb.PartitionChange.MetadataEntry\x12\r\n\x05level\x18\x06 \x01(\x05\x12(\n\x0b\x62\x61tch_items\x18\x07 \x03(\x0b\x32\x13.anndb_pb.BatchItem\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x16\x44\x61tasetManagerSnapshot\x12#\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x11.anndb_pb.Dataset*1\n\x05Space\x12\r\n\tEuclidean\x10\x00\x12\r\n\tManhattan\x10\x01\x12\n\n\x06\x43osine\x10\x02*\x84\x01\n\x18\x44\x61tasetManagerChangeType\x12\x1f\n\x1b\x44\x61tasetManagerCreateDataset\x10\x00\x12\x1f\n\x1b\x44\x61tasetManagerDeleteDataset\x10\x01\x12&\n\"DatasetManagerUpdatePartitionNodes\x10\x02*t\n\x1f\x44\x61tasetPartitionNodesChangeType\x12&\n\"DatasetPartitionNodesChangeAddNode\x10\x00\x12)\n%DatasetPartitionNodesChangeRemoveNode\x10\x01*\xe4\x01\n\x13PartitionChangeType\x12\x1e\n\x1aPartitionChangeInsertValue\x10\x00\x12\x1e\n\x1aPartitionChangeUpdateValue\x10\x01\x12\x1e\n\x1aPartitionChangeDeleteValue\x10\x02\x12#\n\x1fPartitionChangeBatchInsertValue\x10\x03\x12#\n\x1fPartitionChangeBatchUpdateValue\x10\x04\x12#\n\x1fPartitionChangeBatchDeleteValue\x10\x05\x32\xdf\x01\n\x0e\x44\x61tasetManager\x12\x33\n\x04List\x12\x16.anndb_pb.EmptyMessage\x1a\x11.anndb_pb.Dataset0\x01\x12/\n\x03Get\x12\x15.anndb_pb.UUIDRequest\x1a\x11.anndb_pb.Dataset\x12.\n\x06\x43reate\x12\x11.anndb_pb.Dataset\x1a\x11.anndb_pb.Dataset\x12\x37\n\x06\x44\x65lete\x12\x15.anndb_pb.UUIDRequest\x1a\x16.anndb_pb.EmptyMessage2\xf4\x04\n\x0b\x44\x61taManager\x12\x39\n\x06Insert\x12\x17.anndb_pb.InsertRequest\x1a\x16.anndb_pb.EmptyMessage\x12\x39\n\x06Update\x12\x17.anndb_pb.UpdateRequest\x1a\x16.anndb_pb.EmptyMessage\x12\x39\n\x06Remove\x12\x17.anndb_pb.RemoveRequest\x1a\x16.anndb_pb.EmptyMessage\x12>\n\x0b\x42\x61tchInsert\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12>\n\x0b\x42\x61tchUpdate\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12>\n\x0b\x42\x61tchRemove\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchInsert\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchUpdate\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchRemove\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponseb\x06proto3')
  ,
  dependencies=[anndb_dot_core__pb2.DESCRIPTOR,])

_SPACE = _descriptor.EnumDescriptor(
  name='Space',
  full_name='anndb_pb.Space',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Euclidean', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Manhattan', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Cosine', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1710,
  serialized_end=1759,
)
_sym_db.RegisterEnumDescriptor(_SPACE)

Space = enum_type_wrapper.EnumTypeWrapper(_SPACE)
_DATASETMANAGERCHANGETYPE = _descriptor.EnumDescriptor(
  name='DatasetManagerChangeType',
  full_name='anndb_pb.DatasetManagerChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerCreateDataset', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerDeleteDataset', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerUpdatePartitionNodes', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1762,
  serialized_end=1894,
)
_sym_db.RegisterEnumDescriptor(_DATASETMANAGERCHANGETYPE)

DatasetManagerChangeType = enum_type_wrapper.EnumTypeWrapper(_DATASETMANAGERCHANGETYPE)
_DATASETPARTITIONNODESCHANGETYPE = _descriptor.EnumDescriptor(
  name='DatasetPartitionNodesChangeType',
  full_name='anndb_pb.DatasetPartitionNodesChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DatasetPartitionNodesChangeAddNode', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetPartitionNodesChangeRemoveNode', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1896,
  serialized_end=2012,
)
_sym_db.RegisterEnumDescriptor(_DATASETPARTITIONNODESCHANGETYPE)

DatasetPartitionNodesChangeType = enum_type_wrapper.EnumTypeWrapper(_DATASETPARTITIONNODESCHANGETYPE)
_PARTITIONCHANGETYPE = _descriptor.EnumDescriptor(
  name='PartitionChangeType',
  full_name='anndb_pb.PartitionChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeInsertValue', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeUpdateValue', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeDeleteValue', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchInsertValue', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchUpdateValue', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchDeleteValue', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2015,
  serialized_end=2243,
)
_sym_db.RegisterEnumDescriptor(_PARTITIONCHANGETYPE)

PartitionChangeType = enum_type_wrapper.EnumTypeWrapper(_PARTITIONCHANGETYPE)
Euclidean = 0
Manhattan = 1
Cosine = 2
DatasetManagerCreateDataset = 0
DatasetManagerDeleteDataset = 1
DatasetManagerUpdatePartitionNodes = 2
DatasetPartitionNodesChangeAddNode = 0
DatasetPartitionNodesChangeRemoveNode = 1
PartitionChangeInsertValue = 0
PartitionChangeUpdateValue = 1
PartitionChangeDeleteValue = 2
PartitionChangeBatchInsertValue = 3
PartitionChangeBatchUpdateValue = 4
PartitionChangeBatchDeleteValue = 5



_INSERTREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.InsertRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.InsertRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.InsertRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_INSERTREQUEST = _descriptor.Descriptor(
  name='InsertRequest',
  full_name='anndb_pb.InsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.InsertRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.InsertRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.InsertRequest.value', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.InsertRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INSERTREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=220,
)


_UPDATEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.UpdateRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.UpdateRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.UpdateRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_UPDATEREQUEST = _descriptor.Descriptor(
  name='UpdateRequest',
  full_name='anndb_pb.UpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.UpdateRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.UpdateRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.UpdateRequest.value', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.UpdateRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=391,
)


_REMOVEREQUEST = _descriptor.Descriptor(
  name='RemoveRequest',
  full_name='anndb_pb.RemoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.RemoveRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.RemoveRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=440,
)


_BATCHITEM_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.BatchItem.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.BatchItem.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchItem.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_BATCHITEM = _descriptor.Descriptor(
  name='BatchItem',
  full_name='anndb_pb.BatchItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.BatchItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchItem.value', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.BatchItem.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='anndb_pb.BatchItem.level', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHITEM_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=598,
)


_BATCHREQUEST = _descriptor.Descriptor(
  name='BatchRequest',
  full_name='anndb_pb.BatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.BatchRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='anndb_pb.BatchRequest.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=670,
)


_PARTITIONBATCHREQUEST = _descriptor.Descriptor(
  name='PartitionBatchRequest',
  full_name='anndb_pb.PartitionBatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.PartitionBatchRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='anndb_pb.PartitionBatchRequest.partition_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='anndb_pb.PartitionBatchRequest.items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=773,
)


_BATCHRESPONSE_ERRORSENTRY = _descriptor.Descriptor(
  name='ErrorsEntry',
  full_name='anndb_pb.BatchResponse.ErrorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.BatchResponse.ErrorsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchResponse.ErrorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=890,
)

_BATCHRESPONSE = _descriptor.Descriptor(
  name='BatchResponse',
  full_name='anndb_pb.BatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='anndb_pb.BatchResponse.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHRESPONSE_ERRORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=890,
)


_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='anndb_pb.Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Dataset.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimension', full_name='anndb_pb.Dataset.dimension', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space', full_name='anndb_pb.Dataset.space', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_count', full_name='anndb_pb.Dataset.partition_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='anndb_pb.Dataset.replication_factor', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='anndb_pb.Dataset.partitions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=1059,
)


_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='anndb_pb.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Partition.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_ids', full_name='anndb_pb.Partition.node_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1102,
)


_DATASETMANAGERCHANGE = _descriptor.Descriptor(
  name='DatasetManagerChange',
  full_name='anndb_pb.DatasetManagerChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.DatasetManagerChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_id', full_name='anndb_pb.DatasetManagerChange.notification_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='anndb_pb.DatasetManagerChange.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1215,
)


_DATASETPARTITIONNODESCHANGE = _descriptor.Descriptor(
  name='DatasetPartitionNodesChange',
  full_name='anndb_pb.DatasetPartitionNodesChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.DatasetPartitionNodesChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.DatasetPartitionNodesChange.dataset_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='anndb_pb.DatasetPartitionNodesChange.partition_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='anndb_pb.DatasetPartitionNodesChange.node_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1363,
)


_PARTITIONCHANGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.PartitionChange.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.PartitionChange.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.PartitionChange.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_PARTITIONCHANGE = _descriptor.Descriptor(
  name='PartitionChange',
  full_name='anndb_pb.PartitionChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.PartitionChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_id', full_name='anndb_pb.PartitionChange.notification_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.PartitionChange.id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.PartitionChange.value', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.PartitionChange.metadata', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='anndb_pb.PartitionChange.level', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_items', full_name='anndb_pb.PartitionChange.batch_items', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARTITIONCHANGE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1645,
)


_DATASETMANAGERSNAPSHOT = _descriptor.Descriptor(
  name='DatasetManagerSnapshot',
  full_name='anndb_pb.DatasetManagerSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasets', full_name='anndb_pb.DatasetManagerSnapshot.datasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=1708,
)

_INSERTREQUEST_METADATAENTRY.containing_type = _INSERTREQUEST
_INSERTREQUEST.fields_by_name['metadata'].message_type = _INSERTREQUEST_METADATAENTRY
_UPDATEREQUEST_METADATAENTRY.containing_type = _UPDATEREQUEST
_UPDATEREQUEST.fields_by_name['metadata'].message_type = _UPDATEREQUEST_METADATAENTRY
_BATCHITEM_METADATAENTRY.containing_type = _BATCHITEM
_BATCHITEM.fields_by_name['metadata'].message_type = _BATCHITEM_METADATAENTRY
_BATCHREQUEST.fields_by_name['items'].message_type = _BATCHITEM
_PARTITIONBATCHREQUEST.fields_by_name['items'].message_type = _BATCHITEM
_BATCHRESPONSE_ERRORSENTRY.containing_type = _BATCHRESPONSE
_BATCHRESPONSE.fields_by_name['errors'].message_type = _BATCHRESPONSE_ERRORSENTRY
_DATASET.fields_by_name['space'].enum_type = _SPACE
_DATASET.fields_by_name['partitions'].message_type = _PARTITION
_DATASETMANAGERCHANGE.fields_by_name['type'].enum_type = _DATASETMANAGERCHANGETYPE
_DATASETPARTITIONNODESCHANGE.fields_by_name['type'].enum_type = _DATASETPARTITIONNODESCHANGETYPE
_PARTITIONCHANGE_METADATAENTRY.containing_type = _PARTITIONCHANGE
_PARTITIONCHANGE.fields_by_name['type'].enum_type = _PARTITIONCHANGETYPE
_PARTITIONCHANGE.fields_by_name['metadata'].message_type = _PARTITIONCHANGE_METADATAENTRY
_PARTITIONCHANGE.fields_by_name['batch_items'].message_type = _BATCHITEM
_DATASETMANAGERSNAPSHOT.fields_by_name['datasets'].message_type = _DATASET
DESCRIPTOR.message_types_by_name['InsertRequest'] = _INSERTREQUEST
DESCRIPTOR.message_types_by_name['UpdateRequest'] = _UPDATEREQUEST
DESCRIPTOR.message_types_by_name['RemoveRequest'] = _REMOVEREQUEST
DESCRIPTOR.message_types_by_name['BatchItem'] = _BATCHITEM
DESCRIPTOR.message_types_by_name['BatchRequest'] = _BATCHREQUEST
DESCRIPTOR.message_types_by_name['PartitionBatchRequest'] = _PARTITIONBATCHREQUEST
DESCRIPTOR.message_types_by_name['BatchResponse'] = _BATCHRESPONSE
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['Partition'] = _PARTITION
DESCRIPTOR.message_types_by_name['DatasetManagerChange'] = _DATASETMANAGERCHANGE
DESCRIPTOR.message_types_by_name['DatasetPartitionNodesChange'] = _DATASETPARTITIONNODESCHANGE
DESCRIPTOR.message_types_by_name['PartitionChange'] = _PARTITIONCHANGE
DESCRIPTOR.message_types_by_name['DatasetManagerSnapshot'] = _DATASETMANAGERSNAPSHOT
DESCRIPTOR.enum_types_by_name['Space'] = _SPACE
DESCRIPTOR.enum_types_by_name['DatasetManagerChangeType'] = _DATASETMANAGERCHANGETYPE
DESCRIPTOR.enum_types_by_name['DatasetPartitionNodesChangeType'] = _DATASETPARTITIONNODESCHANGETYPE
DESCRIPTOR.enum_types_by_name['PartitionChangeType'] = _PARTITIONCHANGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InsertRequest = _reflection.GeneratedProtocolMessageType('InsertRequest', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _INSERTREQUEST_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.InsertRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _INSERTREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.InsertRequest)
  ))
_sym_db.RegisterMessage(InsertRequest)
_sym_db.RegisterMessage(InsertRequest.MetadataEntry)

UpdateRequest = _reflection.GeneratedProtocolMessageType('UpdateRequest', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _UPDATEREQUEST_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.UpdateRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _UPDATEREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.UpdateRequest)
  ))
_sym_db.RegisterMessage(UpdateRequest)
_sym_db.RegisterMessage(UpdateRequest.MetadataEntry)

RemoveRequest = _reflection.GeneratedProtocolMessageType('RemoveRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.RemoveRequest)
  ))
_sym_db.RegisterMessage(RemoveRequest)

BatchItem = _reflection.GeneratedProtocolMessageType('BatchItem', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _BATCHITEM_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.BatchItem.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _BATCHITEM,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchItem)
  ))
_sym_db.RegisterMessage(BatchItem)
_sym_db.RegisterMessage(BatchItem.MetadataEntry)

BatchRequest = _reflection.GeneratedProtocolMessageType('BatchRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchRequest)
  ))
_sym_db.RegisterMessage(BatchRequest)

PartitionBatchRequest = _reflection.GeneratedProtocolMessageType('PartitionBatchRequest', (_message.Message,), dict(
  DESCRIPTOR = _PARTITIONBATCHREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.PartitionBatchRequest)
  ))
_sym_db.RegisterMessage(PartitionBatchRequest)

BatchResponse = _reflection.GeneratedProtocolMessageType('BatchResponse', (_message.Message,), dict(

  ErrorsEntry = _reflection.GeneratedProtocolMessageType('ErrorsEntry', (_message.Message,), dict(
    DESCRIPTOR = _BATCHRESPONSE_ERRORSENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.BatchResponse.ErrorsEntry)
    ))
  ,
  DESCRIPTOR = _BATCHRESPONSE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchResponse)
  ))
_sym_db.RegisterMessage(BatchResponse)
_sym_db.RegisterMessage(BatchResponse.ErrorsEntry)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), dict(
  DESCRIPTOR = _DATASET,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Dataset)
  ))
_sym_db.RegisterMessage(Dataset)

Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), dict(
  DESCRIPTOR = _PARTITION,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Partition)
  ))
_sym_db.RegisterMessage(Partition)

DatasetManagerChange = _reflection.GeneratedProtocolMessageType('DatasetManagerChange', (_message.Message,), dict(
  DESCRIPTOR = _DATASETMANAGERCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetManagerChange)
  ))
_sym_db.RegisterMessage(DatasetManagerChange)

DatasetPartitionNodesChange = _reflection.GeneratedProtocolMessageType('DatasetPartitionNodesChange', (_message.Message,), dict(
  DESCRIPTOR = _DATASETPARTITIONNODESCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetPartitionNodesChange)
  ))
_sym_db.RegisterMessage(DatasetPartitionNodesChange)

PartitionChange = _reflection.GeneratedProtocolMessageType('PartitionChange', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARTITIONCHANGE_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.PartitionChange.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _PARTITIONCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.PartitionChange)
  ))
_sym_db.RegisterMessage(PartitionChange)
_sym_db.RegisterMessage(PartitionChange.MetadataEntry)

DatasetManagerSnapshot = _reflection.GeneratedProtocolMessageType('DatasetManagerSnapshot', (_message.Message,), dict(
  DESCRIPTOR = _DATASETMANAGERSNAPSHOT,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetManagerSnapshot)
  ))
_sym_db.RegisterMessage(DatasetManagerSnapshot)


_INSERTREQUEST_METADATAENTRY._options = None
_UPDATEREQUEST_METADATAENTRY._options = None
_BATCHITEM_METADATAENTRY._options = None
_BATCHRESPONSE_ERRORSENTRY._options = None
_PARTITIONCHANGE_METADATAENTRY._options = None

_DATASETMANAGER = _descriptor.ServiceDescriptor(
  name='DatasetManager',
  full_name='anndb_pb.DatasetManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2246,
  serialized_end=2469,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='anndb_pb.DatasetManager.List',
    index=0,
    containing_service=None,
    input_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='anndb_pb.DatasetManager.Get',
    index=1,
    containing_service=None,
    input_type=anndb_dot_core__pb2._UUIDREQUEST,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='anndb_pb.DatasetManager.Create',
    index=2,
    containing_service=None,
    input_type=_DATASET,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='anndb_pb.DatasetManager.Delete',
    index=3,
    containing_service=None,
    input_type=anndb_dot_core__pb2._UUIDREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASETMANAGER)

DESCRIPTOR.services_by_name['DatasetManager'] = _DATASETMANAGER


_DATAMANAGER = _descriptor.ServiceDescriptor(
  name='DataManager',
  full_name='anndb_pb.DataManager',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=2472,
  serialized_end=3100,
  methods=[
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='anndb_pb.DataManager.Insert',
    index=0,
    containing_service=None,
    input_type=_INSERTREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='anndb_pb.DataManager.Update',
    index=1,
    containing_service=None,
    input_type=_UPDATEREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Remove',
    full_name='anndb_pb.DataManager.Remove',
    index=2,
    containing_service=None,
    input_type=_REMOVEREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchInsert',
    full_name='anndb_pb.DataManager.BatchInsert',
    index=3,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchUpdate',
    full_name='anndb_pb.DataManager.BatchUpdate',
    index=4,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchRemove',
    full_name='anndb_pb.DataManager.BatchRemove',
    index=5,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchInsert',
    full_name='anndb_pb.DataManager.PartitionBatchInsert',
    index=6,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchUpdate',
    full_name='anndb_pb.DataManager.PartitionBatchUpdate',
    index=7,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchRemove',
    full_name='anndb_pb.DataManager.PartitionBatchRemove',
    index=8,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAMANAGER)

DESCRIPTOR.services_by_name['DataManager'] = _DATAMANAGER

# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

VERSION = '0.0.4'

setup(name='anndb',
    version=VERSION,
    description='AnnDB Client',
    author='Marek Galovic',
    author_email='galovic.galovic@gmail.com',
    license='MIT',
    url='https://github.com/marekgalovic/anndb-client-python',
    download_url='https://github.com/marekgalovic/anndb-client-python/archive/%s.tar.gz' % VERSION,
    packages=find_packages(),
    zip_safe=False,
    install_requires=[
        'google',
        'grpcio'
    ],
)